#[non_exhaustive]pub struct UnparsedRegion {
pub offset: u64,
pub length: u64,
pub reason: SkipReason,
pub data: Option<Vec<u8>>,
}Expand description
A contiguous region of the input that was not parsed into a frame.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.offset: u64Byte offset from the start of the input stream.
length: u64Number of bytes in this region.
reason: SkipReasonWhy this region was skipped.
data: Option<Vec<u8>>The raw bytes, populated only when SkipTracking::CaptureData is enabled.